@@ -177,6 +177,7 @@ from bitmovin_api_sdk.models.broadcast_ts_video_input_stream_configuration impor
 from bitmovin_api_sdk.models.burn_in_subtitle_dvb_sub import BurnInSubtitleDvbSub
 from bitmovin_api_sdk.models.burn_in_subtitle_srt import BurnInSubtitleSrt
 from bitmovin_api_sdk.models.caption_character_encoding import CaptionCharacterEncoding
+from bitmovin_api_sdk.models.cdn_output import CdnOutput
 from bitmovin_api_sdk.models.cea608708_subtitle_configuration import Cea608708SubtitleConfiguration
 from bitmovin_api_sdk.models.cea608_caption_input_stream import Cea608CaptionInputStream
 from bitmovin_api_sdk.models.cea608_channel_type import Cea608ChannelType
@@ -603,13 +604,15 @@ from bitmovin_api_sdk.models.sidecar_file import SidecarFile
 from bitmovin_api_sdk.models.sidecar_file_type import SidecarFileType
 from bitmovin_api_sdk.models.signature_type import SignatureType
 from bitmovin_api_sdk.models.simple_encoding_live_cloud_region import SimpleEncodingLiveCloudRegion
-from bitmovin_api_sdk.models.simple_encoding_live_input_aspect_ratio import SimpleEncodingLiveInputAspectRatio
 from bitmovin_api_sdk.models.simple_encoding_live_job_access_key_credentials import SimpleEncodingLiveJobAccessKeyCredentials
 from bitmovin_api_sdk.models.simple_encoding_live_job_azure_credentials import SimpleEncodingLiveJobAzureCredentials
+from bitmovin_api_sdk.models.simple_encoding_live_job_cdn_output import SimpleEncodingLiveJobCdnOutput
 from bitmovin_api_sdk.models.simple_encoding_live_job_credentials import SimpleEncodingLiveJobCredentials
 from bitmovin_api_sdk.models.simple_encoding_live_job_gcs_service_account_credentials import SimpleEncodingLiveJobGcsServiceAccountCredentials
 from bitmovin_api_sdk.models.simple_encoding_live_job_input import SimpleEncodingLiveJobInput
 from bitmovin_api_sdk.models.simple_encoding_live_job_input_type import SimpleEncodingLiveJobInputType
+from bitmovin_api_sdk.models.simple_encoding_live_job_output import SimpleEncodingLiveJobOutput
+from bitmovin_api_sdk.models.simple_encoding_live_job_output_type import SimpleEncodingLiveJobOutputType
 from bitmovin_api_sdk.models.simple_encoding_live_job_request import SimpleEncodingLiveJobRequest
 from bitmovin_api_sdk.models.simple_encoding_live_job_response import SimpleEncodingLiveJobResponse
 from bitmovin_api_sdk.models.simple_encoding_live_job_s3_role_based_credentials import SimpleEncodingLiveJobS3RoleBasedCredentials
@@ -619,10 +622,13 @@ from bitmovin_api_sdk.models.simple_encoding_live_job_username_password_credenti
 from bitmovin_api_sdk.models.simple_encoding_live_max_resolution import SimpleEncodingLiveMaxResolution
 from bitmovin_api_sdk.models.simple_encoding_vod_job_access_key_credentials import SimpleEncodingVodJobAccessKeyCredentials
 from bitmovin_api_sdk.models.simple_encoding_vod_job_azure_credentials import SimpleEncodingVodJobAzureCredentials
+from bitmovin_api_sdk.models.simple_encoding_vod_job_cdn_output import SimpleEncodingVodJobCdnOutput
 from bitmovin_api_sdk.models.simple_encoding_vod_job_credentials import SimpleEncodingVodJobCredentials
 from bitmovin_api_sdk.models.simple_encoding_vod_job_errors import SimpleEncodingVodJobErrors
 from bitmovin_api_sdk.models.simple_encoding_vod_job_gcs_service_account_credentials import SimpleEncodingVodJobGcsServiceAccountCredentials
 from bitmovin_api_sdk.models.simple_encoding_vod_job_input_type import SimpleEncodingVodJobInputType
+from bitmovin_api_sdk.models.simple_encoding_vod_job_output import SimpleEncodingVodJobOutput
+from bitmovin_api_sdk.models.simple_encoding_vod_job_output_type import SimpleEncodingVodJobOutputType
 from bitmovin_api_sdk.models.simple_encoding_vod_job_request import SimpleEncodingVodJobRequest
 from bitmovin_api_sdk.models.simple_encoding_vod_job_response import SimpleEncodingVodJobResponse
 from bitmovin_api_sdk.models.simple_encoding_vod_job_s3_role_based_credentials import SimpleEncodingVodJobS3RoleBasedCredentials
